.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT



.. _canary_cmake.cdash.cdash_html_summary:

cdash_html_summary
==================

.. automodule:: canary_cmake.cdash.cdash_html_summary
   :members:
   :undoc-members:
   :show-inheritance:
